@@ -3,7 +3,7 @@ package Games::Framework::RCP::Database::Result::Class;
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use base qw/DBIx::Class/;
 
@@ -137,11 +137,11 @@ __END__
 
 =head1 NAME
 
-Games::Framework::RCP::Database::Result::Class
+Games::Framework::RCP::Database::Result::Class - Simple listing of all jobs and their stats.
 
 =head1 VERSION
 
-0.21
+0.22
 
 =head1 DESCRIPTION
 
