@@ -3,7 +3,7 @@ package Games::Framework::RCP::Database::Result::ClassKind;
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use base qw/DBIx::Class/;
 
@@ -50,11 +50,11 @@ __END__
 
 =head1 NAME
 
-Games::Framework::RCP::Database::Result::ClassKind
+Games::Framework::RCP::Database::Result::ClassKind - A list of the various types of classes.
 
 =head1 VERSION
 
-0.21
+0.22
 
 =head1 DESCRIPTION
 
