@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use base qw/DBIx::Class/;
 
@@ -65,11 +65,11 @@ __END__
 
 =head1 NAME
 
-Games::Framework::RCP::Database::Result::ItemWithStat
+Games::Framework::RCP::Database::Result::ItemWithStat - Every item that gives a stat change upon using.
 
 =head1 VERSION
 
-0.21
+0.22
 
 =head1 DESCRIPTION
 
