@@ -3,7 +3,7 @@ package Games::Framework::RCP::Database::Result::MoveWithFlag;
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use base qw/DBIx::Class/;
 
@@ -50,11 +50,11 @@ __END__
 
 =head1 NAME
 
-Games::Framework::RCP::Database::Result::MoveWithFlag
+Games::Framework::RCP::Database::Result::MoveWithFlag - Every move with all of the possible flags.
 
 =head1 VERSION
 
-0.21
+0.22
 
 =head1 DESCRIPTION
 
