@@ -3,7 +3,7 @@ package Games::Framework::RCP::Database::Result::StartingStatus;
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use base qw/DBIx::Class/;
 
@@ -60,11 +60,11 @@ __END__
 
 =head1 NAME
 
-Games::Framework::RCP::Database::Result::StartingStatus
+Games::Framework::RCP::Database::Result::StartingStatus - The status effects classes start with.
 
 =head1 VERSION
 
-0.21
+0.22
 
 =head1 DESCRIPTION
 
