@@ -3,7 +3,7 @@ package Games::Framework::RCP::Database::Result::VarBool;
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use base qw/DBIx::Class/;
 
@@ -48,11 +48,11 @@ __END__
 
 =head1 NAME
 
-Games::Framework::RCP::Database::Result::VarBool
+Games::Framework::RCP::Database::Result::VarBool - List of boolean variables.
 
 =head1 VERSION
 
-0.21
+0.22
 
 =head1 DESCRIPTION
 
